@@ -40,6 +40,7 @@ Submodules
 
 """
 
+from .version import __version__
 from .exceptions import QiskitFinanceError
 
-__all__ = ['QiskitFinanceError']
+__all__ = ["__version__", "QiskitFinanceError"]
